==> farfetch_api-0.1.4.tar.gz: farfetch_api-0.1.4/src/farfetch/returns.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Farfetch API
# Copyright (c) 2008-2015 Hive Solutions Lda.
#
# This file is part of Hive Farfetch API.
#
# Hive Farfetch API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Farfetch API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Farfetch API. If not, see <http://www.apache.org/licenses/>.

__author__ = "Rui Castro <rui.castro@gmail.com>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

class ReturnApi(object):

    def get_return(self, id):
        url = self.base_url + "returns/%s" % id
        contents = self.get(url)
        return contents

    def get_awb_return(self, id):
        url = self.base_url + "returns/%s/AWB" % id
        contents = self.get(url)
        return contents

    def get_invoice_return(self, id):
        url = self.base_url + "returns/%s/Invoice" % id
        contents = self.get(url)
        return contents

    def create_return(self, return_data):
        url = self.base_url + "returns"
        contents = self.post(url, data_j = return_data)
        return contents

    def update_return(self, id, return_data):
        url = self.base_url + "returns/%s" % id
        contents = self.patch(url, data_j = return_data)
        return contents

    def pickup_capabilities_return(self, id, day):
        url = self.base_url + "returns/%s/pickupCapabilities/%s" % (id, day)
        contents = self.get(url)
        return contents

==> farfetch_api-0.1.5.tar.gz: farfetch_api-0.1.5/src/farfetch/returns.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Farfetch API
# Copyright (c) 2008-2015 Hive Solutions Lda.
#
# This file is part of Hive Farfetch API.
#
# Hive Farfetch API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Farfetch API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Farfetch API. If not, see <http://www.apache.org/licenses/>.

__author__ = "Rui Castro <rui.castro@gmail.com>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

class ReturnApi(object):

    def get_return(self, id):
        url = self.base_url + "returns/%s" % id
        contents = self.get(url)
        return contents

    def return_awb(self, id):
        url = self.base_url + "returns/%s/AWB" % id
        contents = self.get(url)
        return contents

    def return_invoice(self, id):
        url = self.base_url + "returns/%s/Invoice" % id
        contents = self.get(url)
        return contents

    def create_return(self, return_data):
        url = self.base_url + "returns"
        contents = self.post(url, data_j = return_data)
        return contents

    def update_return(self, id, return_data):
        url = self.base_url + "returns/%s" % id
        contents = self.patch(url, data_j = return_data)
        return contents

    def return_pickup_capabilities(self, id, day):
        url = self.base_url + "returns/%s/pickupCapabilities/%s" % (id, day)
        contents = self.get(url)
        return contents
